.. _api:

Developer Interface
===================

.. module:: signaling


Signal
------

.. autoclass:: Signal
   :members:


Exceptions
----------

.. autoexception:: signaling.exceptions.InvalidSlot
.. autoexception:: signaling.exceptions.InvalidEmit
